.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

neuroboom
=======================

**Welcome to neuroboom**!

.. image:: /_static/logos/nb_small_logo.png
    :width: 1200
    :class: with-shadow

Neuroboom is a suite of Python3 tools for analysing neuron reconstructions within Connectomic initiatives.
Neuroboom is currently designed to operate on neuron recontructions within the *CATMAID* or *Neuprint* platforms.

These two different platforms reflect the two available connectomic efforts in the fruit fly, Drosophila melanogaster:

1. the `Full Adult Female Brain (FAFB) <https://www.sciencedirect.com/science/article/pii/S0092867418307876?via%3Dihub>`_ Zheng *et al.*, 2018, *Cell*
2. the `Hemibrain <https://elifesciences.org/articles/57443>`_, Scheffer *et al.*, 2020, *eLife*


Some code incorporated within the neuroboom package has been presented in scientific papers, most notably the **dendrogram** functions:

1. `Integration of Parallel Opposing Memories Underlies Memory Extinction <https://www.sciencedirect.com/science/article/pii/S0092867418310377?via%3Dihub>`_, J. Felsenberg *et al.*, 2018, *Cell*
2. `Input Connectivity Reveals Additional Heterogeneity of Dopaminergic Reinforcement in Drosophila <https://www.cell.com/current-biology/fulltext/S0960-9822(20)30764-8>`_, N. Otto, **MW Pleijzier** *et al.*, 2018, *Current Biology*
3. `Convergence of distinct subpopulations of mechanosensory neurons onto a neural circuit that elicits grooming <https://www.biorxiv.org/content/10.1101/2020.06.08.141341v1>`_, S. Hampel *et al.*, 2020, *biorXiv*


.. toctree::
   :maxdepth: 1

   installation
   usage
   dendrogram_tutorial
   release-history
   min_versions
